# tensor-store

[![Test and deploy](https://github.com/hydrocode-de/tensorage/actions/workflows/main.yml/badge.svg)](https://github.com/hydrocode-de/tensorage/actions/workflows/main.yml)
[![codecov](https://codecov.io/gh/hydrocode-de/tensorage/graph/badge.svg?token=1eF6OGb9XW)](https://codecov.io/gh/hydrocode-de/tensorage)

Store tensor data structures into Supabase

A detailed getting started will follow soon!